@@ -415,7 +415,11 @@ impl Workspace {
 
         let offset = position.to_text_size(&source, &index, self.position_encoding)?;
 
-        let completions = ty_ide::completion(&self.db, file_id.file, offset);
+        // NOTE: At time of writing, 2025-08-29, auto-import isn't
+        // ready to be enabled by default yet. Once it is, we should
+        // either just enable it or provide a way to configure it.
+        let settings = ty_ide::CompletionSettings { auto_import: false };
+        let completions = ty_ide::completion(&self.db, &settings, file_id.file, offset);
 
         Ok(completions
             .into_iter()
@@ -425,6 +429,10 @@ impl Workspace {
                 documentation: completion
                     .documentation
                     .map(|documentation| documentation.render_plaintext()),
+                detail: completion
+                    .inner
+                    .ty
+                    .map(|ty| ty.display(&self.db).to_string()),
             })
             .collect())
     }
@@ -448,13 +456,14 @@ impl Workspace {
         Ok(result
             .into_iter()
             .map(|hint| InlayHint {
-                markdown: hint.display(&self.db).to_string(),
+                markdown: hint.display().to_string(),
                 position: Position::from_text_size(
                     hint.position,
                     &index,
                     &source,
                     self.position_encoding,
                 ),
+                kind: hint.kind.into(),
             })
             .collect())
     }
@@ -913,6 +922,8 @@ pub struct Completion {
     pub kind: Option<CompletionKind>,
     #[wasm_bindgen(getter_with_clone)]
     pub documentation: Option<String>,
+    #[wasm_bindgen(getter_with_clone)]
+    pub detail: Option<String>,
 }
 
 #[wasm_bindgen]
@@ -977,6 +988,22 @@ impl From<ty_python_semantic::CompletionKind> for CompletionKind {
     }
 }
 
+#[wasm_bindgen]
+#[derive(Debug, Clone, PartialEq, Eq, Copy)]
+pub enum InlayHintKind {
+    Type,
+    Parameter,
+}
+
+impl From<ty_ide::InlayHintKind> for InlayHintKind {
+    fn from(kind: ty_ide::InlayHintKind) -> Self {
+        match kind {
+            ty_ide::InlayHintKind::Type => Self::Type,
+            ty_ide::InlayHintKind::CallArgumentName => Self::Parameter,
+        }
+    }
+}
+
 #[wasm_bindgen]
 #[derive(Debug, Clone, PartialEq, Eq)]
 pub struct InlayHint {
@@ -984,6 +1011,8 @@ pub struct InlayHint {
     pub markdown: String,
 
     pub position: Position,
+
+    pub kind: InlayHintKind,
 }
 
 #[wasm_bindgen]
@@ -1209,6 +1238,10 @@ impl System for WasmSystem {
     fn as_any_mut(&mut self) -> &mut dyn Any {
         self
     }
+
+    fn dyn_clone(&self) -> Box<dyn System> {
+        Box::new(self.clone())
+    }
 }
 
 fn not_found() -> std::io::Error {
